agentle.mcp.session\_management
===============================

.. automodule:: agentle.mcp.session_management

   
   .. rubric:: Classes

   .. autosummary::
   
      InMemorySessionManager
      RedisSessionManager
      SessionManager
   
.. rubric:: Modules

.. autosummary::
   :toctree:
   :recursive:

   in_memory
   redis
   session_manager
